{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmsearch"
            ],
            "inputs": [
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/covariance_model_database",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/cpu",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--cpu"
                    },
                    "label": "Number of parallel CPU workers to use for multithreads"
                },
                {
                    "default": false,
                    "id": "#infernal-cmsearch-v1.1.2.cwl/cut_ga",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--cut_ga"
                    },
                    "label": "use CM's GA gathering cutoffs as reporting thresholds"
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/omit_alignment_section",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--noali"
                    },
                    "label": "Omit the alignment section from the main output.",
                    "doc": "This can greatly reduce the output volume."
                },
                {
                    "default": false,
                    "id": "#infernal-cmsearch-v1.1.2.cwl/only_hmm",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--hmmonly"
                    },
                    "label": "Only use the filter profile HMM for searches, do not use the CM",
                    "doc": "Only filter stages F1 through F3 will be executed, using strict P-value\nthresholds (0.02 for F1, 0.001 for F2 and 0.00001 for F3). Additionally\na bias composition filter is used after the F1 stage (with P=0.02\nsurvival threshold). Any hit that survives all stages and has an HMM\nE-value or bit score above the reporting threshold will be output.\n"
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "id": "#infernal-cmsearch-v1.1.2.cwl/query_sequences",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "streamable": true
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/search_space_size",
                    "type": "int",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-Z"
                    },
                    "label": "search space size in *Mb* to <x> for E-value calculations"
                }
            ],
            "doc": "Infernal (\"INFERence of RNA ALignment\") is for searching DNA sequence databases for RNA structure and sequence similarities. It is an implementation of a special case of profile stochastic context-free grammars called covariance models (CMs). A CM is like a sequence profile, but it scores a combination of sequence consensus and RNA secondary structure consensus, so in many cases, it is more capable of identifying RNA homologs that conserve their secondary structure more than their primary sequence.\nPlease visit http://eddylab.org/infernal/ for full documentation.\nVersion 1.1.2 can be downloaded from http://eddylab.org/infernal/infernal-1.1.2.tar.gz\n",
            "label": "Search sequence(s) against a covariance model database",
            "arguments": [
                {
                    "position": 0,
                    "prefix": "--tblout",
                    "valueFrom": "$(inputs.query_sequences.basename).cmsearch_matches.tbl"
                },
                {
                    "position": 0,
                    "prefix": "-o",
                    "valueFrom": "$(inputs.query_sequences.basename).cmsearch.out"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011809"
                            ],
                            "version": [
                                "1.1.2"
                            ],
                            "package": "infernal"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/infernal:1.1.2--h470a237_1"
                },
                {
                    "class": "http://galaxyproject.org/cwl#interface",
                    "http://galaxyproject.org/cwl#inputs": [
                        {
                            "http://galaxyproject.org/cwl#name": "covariance_model_database",
                            "http://galaxyproject.org/cwl#type": "data",
                            "http://galaxyproject.org/cwl#format": "txt"
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "cpu",
                            "http://galaxyproject.org/cwl#type": "integer",
                            "http://galaxyproject.org/cwl#optional": true
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "cut_ga",
                            "http://galaxyproject.org/cwl#type": "boolean",
                            "http://galaxyproject.org/cwl#optional": true
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "omit_alignment_section",
                            "http://galaxyproject.org/cwl#type": "boolean",
                            "http://galaxyproject.org/cwl#optional": true
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "only_hmm",
                            "http://galaxyproject.org/cwl#type": "boolean",
                            "http://galaxyproject.org/cwl#optional": true
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "query_sequences",
                            "http://galaxyproject.org/cwl#type": "data",
                            "http://galaxyproject.org/cwl#format": "txt"
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "search_space_size",
                            "http://galaxyproject.org/cwl#type": "integer",
                            "http://galaxyproject.org/cwl#default_value": 1000,
                            "http://galaxyproject.org/cwl#optional": true
                        }
                    ]
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2048,
                    "ramMax": 8192,
                    "coresMin": 4
                }
            ],
            "id": "#infernal-cmsearch-v1.1.2.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew",
            "outputs": [
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/matches",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "label": "target hits table, format 2",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.query_sequences.basename).cmsearch_matches.tbl"
                    }
                },
                {
                    "id": "#infernal-cmsearch-v1.1.2.cwl/programOutput",
                    "label": "direct output to file, not stdout",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.query_sequences.basename).cmsearch.out"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cmsearch-deoverlap.pl"
            ],
            "inputs": [
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/clan_information",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--clanin"
                    },
                    "label": "clan information on the models provided",
                    "doc": "Not all models provided need to be a member of a clan"
                },
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/cmsearch_matches",
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#cmsearch-deoverlap-v0.02.cwl/deoverlapped_matches",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "label": "target hits table, format 2",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.deoverlapped"
                    }
                }
            ],
            "doc": "https://github.com/nawrockie/cmsearch_tblout_deoverlap/blob/master/00README.txt",
            "label": "Remove lower scoring overlaps from cmsearch --tblout files.",
            "requirements": [
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envValue": "C",
                            "envName": "LC_ALL"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 100,
                    "coresMax": 1
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.cmsearch_matches)"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://github.com/nawrockie/cmsearch_tblout_deoverlap"
                            ],
                            "version": [
                                "0.02"
                            ],
                            "package": "cmsearch_tblout_deoverlap"
                        }
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biocrusoe/cmsearch-deoverlap"
                },
                {
                    "class": "http://galaxyproject.org/cwl#interface",
                    "http://galaxyproject.org/cwl#inputs": [
                        {
                            "http://galaxyproject.org/cwl#name": "clan_information",
                            "http://galaxyproject.org/cwl#type": "data",
                            "http://galaxyproject.org/cwl#format": "txt",
                            "http://galaxyproject.org/cwl#optional": true
                        },
                        {
                            "http://galaxyproject.org/cwl#name": "cmsearch_matches",
                            "http://galaxyproject.org/cwl#type": "data",
                            "http://galaxyproject.org/cwl#format": "txt"
                        }
                    ]
                }
            ],
            "id": "#cmsearch-deoverlap-v0.02.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cat"
            ],
            "inputs": [
                {
                    "id": "#concatenate.cwl/files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "streamable": true
                },
                {
                    "id": "#concatenate.cwl/outputFileName",
                    "type": "string"
                }
            ],
            "outputs": [
                {
                    "id": "#concatenate.cwl/result",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputFileName)",
                        "outputEval": "${ self[0].format = inputs.files[0].format;\n   return self; }\n"
                    }
                }
            ],
            "doc": "The cat (short for \u201cconcatenate\u201c) command is one of the most frequently used command in Linux/Unix like operating systems. cat command allows us to create single or multiple files, view contain of file, concatenate files and redirect output in terminal or files.\n",
            "label": "Redirecting Multiple Files Contain in a Single File",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 100,
                    "coresMax": 1
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "stdout": "$(inputs.outputFileName)",
            "id": "#concatenate.cwl",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Michael Crusoe, Maxim Scheremetjew"
        },
        {
            "class": "Workflow",
            "label": "Identifies non-coding RNAs using Rfams covariance models",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "cat_cmsearch_matches.tbl",
                    "id": "#main/catOutputFileName"
                },
                {
                    "type": "File",
                    "id": "#main/clan_info"
                },
                {
                    "type": "int",
                    "id": "#main/cores"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#main/query_sequences"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/cmsearch/matches",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/cmsearch_matches"
                },
                {
                    "outputSource": "#main/run_concatenate_matches/result",
                    "type": "File",
                    "id": "#main/concatenate_matches"
                },
                {
                    "outputSource": "#main/remove_overlaps/deoverlapped_matches",
                    "type": "File",
                    "id": "#main/deoverlapped_matches"
                }
            ],
            "steps": [
                {
                    "label": "Search sequence(s) against a covariance model database",
                    "run": "#infernal-cmsearch-v1.1.2.cwl",
                    "in": [
                        {
                            "source": "#main/covariance_models",
                            "id": "#main/cmsearch/covariance_model_database"
                        },
                        {
                            "source": "#main/cores",
                            "id": "#main/cmsearch/cpu"
                        },
                        {
                            "default": true,
                            "id": "#main/cmsearch/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#main/cmsearch/only_hmm"
                        },
                        {
                            "source": "#main/query_sequences",
                            "id": "#main/cmsearch/query_sequences"
                        },
                        {
                            "default": 1000,
                            "id": "#main/cmsearch/search_space_size"
                        }
                    ],
                    "scatter": "#main/cmsearch/covariance_model_database",
                    "out": [
                        "#main/cmsearch/matches",
                        "#main/cmsearch/programOutput"
                    ],
                    "id": "#main/cmsearch"
                },
                {
                    "label": "Remove lower scoring overlaps from cmsearch --tblout files.",
                    "run": "#cmsearch-deoverlap-v0.02.cwl",
                    "in": [
                        {
                            "source": "#main/clan_info",
                            "id": "#main/remove_overlaps/clan_information"
                        },
                        {
                            "source": "#main/run_concatenate_matches/result",
                            "id": "#main/remove_overlaps/cmsearch_matches"
                        }
                    ],
                    "out": [
                        "#main/remove_overlaps/deoverlapped_matches"
                    ],
                    "id": "#main/remove_overlaps"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#main/cmsearch/matches",
                            "id": "#main/run_concatenate_matches/files"
                        },
                        {
                            "source": "#main/catOutputFileName",
                            "id": "#main/run_concatenate_matches/outputFileName"
                        }
                    ],
                    "out": [
                        "#main/run_concatenate_matches/result"
                    ],
                    "id": "#main/run_concatenate_matches"
                }
            ],
            "id": "#main",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Maxim Scheremetjew"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
